#   ipmkchains_constants.py -- Constants for ipmkchains
#   Copyright (C) 2000  Bruce Guenter <bruceg@em.ca>
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

# Built in chain names
INPUT = intern('input')
FORWARD = intern('forward')
OUTPUT = intern('output')

CHAINS = [INPUT, FORWARD, OUTPUT]

# Predefined target names
ACCEPT   = intern('ACCEPT')
REJECT   = intern('REJECT')
DENY     = intern('DENY')
MASQ     = intern('MASQ')
REDIRECT = intern('REDIRECT')
RETURN   = intern('RETURN')

# Predefined protocol types
ICMP=1
IGMP=2
OSPF=89
TCP=6
UDP=17

icmp_types = {
    'echo-reply':(0,-1),
    'pong':(0,-1),
    'destination-unreachable':(3,-1),
    'network-unreachable':(3,0),
    'host-unreachable':(3,1),
    'protocol-unreachable':(3,2),
    'port-unreachable':(3,3),
    'fragmentation-needed':(3,4),
    'source-route-failed':(3,5),
    'network-unknown':(3,6),
    'host-unknown':(3,7),
    'network-prohibited':(3,9),
    'host-prohibited':(3,10),
    'TOS-network-unreachable':(3,11),
    'TOS-host-unreachable':(3,12),
    'communication-prohibited':(3,13),
    'host-precedence-violation':(3,14),
    'precedence-cutoff':(3,15),
    'source-quench':(4,-1),
    'redirect':(5,-1),
    'network-redirect':(5,0),
    'host-redirect':(5,1),
    'TOS-network-redirect':(5,2),
    'TOS-host-redirect':(5,3),
    'echo-request':(8,-1),
    'ping':(8,-1),
    'router-advertisement':(9,-1),
    'router-solicitation':(10,-1),
    'time-exceeded':(11,-1),
    'ttl-exceeded':(11,-1),
    'ttl-zero-during-transit':(11,0),
    'ttl-zero-during-reassembly':(11,1),
    'parameter-problem':(12,-1),
    'ip-header-bad':(12,0),
    'required-option-missing':(12,1),
    'timestamp-request':(13,-1),
    'timestamp-reply':(14,-1),
    'address-mask-request':(17,-1),
    'address-mask-reply':(18,-1),
    }

FLAG1_LOG = 0x01
FLAG1_SYN = 0x02
FLAG1_FRAG = 0x04
FLAG1_SETMARK = 0x08
FLAG1_ANYIFACE = 0x10
FLAG1_OUTPUT = 0x20

FLAG2_SRCIP = 0x01
FLAG2_DSTIP = 0x02
FLAG2_PROTO = 0x04
FLAG2_SRCPORT = 0x08
FLAG2_DSTPORT = 0x10
FLAG2_IFACE = 0x20
FLAG2_SYN = 0x40
FLAG2_FRAG = 0x80

IP_ALLONES = (255,255,255,255)
IP_ALLZEROS = (0,0,0,0)

mask2bits = {
    (0,0,0,0): 0,
    (128,0,0,0): 1,
    (192,0,0,0): 2,
    (224,0,0,0): 3,
    (240,0,0,0): 4,
    (248,0,0,0): 5,
    (252,0,0,0): 6,
    (254,0,0,0): 7,
    (255,0,0,0): 8,
    (255,128,0,0): 9,
    (255,192,0,0): 10,
    (255,224,0,0): 11,
    (255,240,0,0): 12,
    (255,248,0,0): 13,
    (255,252,0,0): 14,
    (255,254,0,0): 15,
    (255,255,0,0): 16,
    (255,255,128,0): 17,
    (255,255,192,0): 18,
    (255,255,224,0): 19,
    (255,255,240,0): 20,
    (255,255,248,0): 21,
    (255,255,252,0): 22,
    (255,255,254,0): 23,
    (255,255,255,0): 24,
    (255,255,255,128): 25,
    (255,255,255,192): 26,
    (255,255,255,224): 27,
    (255,255,255,240): 28,
    (255,255,255,248): 29,
    (255,255,255,252): 30,
    (255,255,255,254): 31,
    (255,255,255,255): 32,
    }
